@@ -1,4 +1,6 @@
 pub mod app;
 pub mod colors;
 pub mod event;
+pub mod pathing;
+pub mod styles;
 pub mod text;
